package com.ruoyi.care.service;

import java.util.List;
import com.ruoyi.care.domain.CareHospital;

/**
 * 医院Service接口
 * 
 * @author ruoyi
 * @date 2024-11-29
 */
public interface ICareHospitalService 
{
    /**
     * 查询医院
     * 
     * @param hospitalId 医院主键
     * @return 医院
     */
    public CareHospital selectCareHospitalByHospitalId(Long hospitalId);

    /**
     * 查询医院列表
     * 
     * @param careHospital 医院
     * @return 医院集合
     */
    public List<CareHospital> selectCareHospitalList(CareHospital careHospital);

    /**
     * 新增医院
     * 
     * @param careHospital 医院
     * @return 结果
     */
    public int insertCareHospital(CareHospital careHospital);

    /**
     * 修改医院
     * 
     * @param careHospital 医院
     * @return 结果
     */
    public int updateCareHospital(CareHospital careHospital);

    /**
     * 批量删除医院
     * 
     * @param hospitalIds 需要删除的医院主键集合
     * @return 结果
     */
    public int deleteCareHospitalByHospitalIds(Long[] hospitalIds);

    /**
     * 删除医院信息
     * 
     * @param hospitalId 医院主键
     * @return 结果
     */
    public int deleteCareHospitalByHospitalId(Long hospitalId);
}
